'use client';
import { Fragment as _Fragment, jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import React, { Suspense, use, useContext, useRef, useState } from 'react';
import { initializeDevCycle, } from '@devcycle/js-client-sdk';
import { useRouter } from 'next/navigation';
import { invalidateConfig } from '../common/invalidateConfig';
export const DevCycleClientContext = React.createContext({});
/**
 * Component which renders nothing, but runs code to keep client state in sync with server
 * Also waits for the server's data promise with the `use` hook. This triggers the nearest suspense boundary,
 * so this component is being rendered inside of a Suspense by the DevCycleClientsideProvider.
 * @param serverDataPromise
 * @constructor
 */
export const SuspendedProviderInitialization = ({ serverDataPromise, }) => {
    const serverData = use(serverDataPromise);
    const [previousContext, setPreviousContext] = useState();
    const context = useContext(DevCycleClientContext);
    if (previousContext !== serverData) {
        // change user and config data to match latest server data
        // if the data has changed since the last invocation
        context.client.synchronizeBootstrapData(serverData.config, serverData.user);
        setPreviousContext(serverData);
    }
    return _jsx(_Fragment, {});
};
export const DevCycleClientsideProvider = ({ context, children, }) => {
    const router = useRouter();
    const clientRef = useRef();
    const { serverDataPromise, serverData, sdkKey, enableStreaming, user } = context;
    const revalidateConfig = (lastModified) => {
        invalidateConfig(sdkKey, lastModified).finally(() => {
            router.refresh();
        });
    };
    if (!clientRef.current) {
        clientRef.current = initializeDevCycle(sdkKey, user, {
            deferInitialization: enableStreaming,
            disableConfigCache: true,
            bootstrapConfig: enableStreaming ? undefined : serverData === null || serverData === void 0 ? void 0 : serverData.config,
            next: {
                configRefreshHandler: revalidateConfig,
            },
        });
    }
    return (_jsxs(DevCycleClientContext.Provider, { value: {
            client: clientRef.current,
            sdkKey: sdkKey,
            enableStreaming,
            serverDataPromise,
        }, children: [enableStreaming && (_jsx(Suspense, { children: _jsx(SuspendedProviderInitialization, { serverDataPromise: serverDataPromise }) })), children] }));
};
//# sourceMappingURL=DevCycleClientsideProvider.js.map