import { getClient, getInitializedPromise } from './requestContext';
/**
 * keep waiting until next tick to ensure that root layout render has been started and the
 * initialization promise has been set. Counterintuitively, Next seems to call the render of pages before layouts
 * Will keep ticking up to 50 times then give up with an error
 */
const waitForPromiseAvailable = async () => {
    let initializedPromise = getInitializedPromise();
    let attempts = 0;
    while (!initializedPromise && attempts < 50) {
        await new Promise((resolve) => setTimeout(resolve));
        initializedPromise = getInitializedPromise();
        attempts++;
    }
    if (!initializedPromise) {
        throw new Error('DevCycle server context not found! Did you wrap the root layout in DevCycleServersideProvider?');
    }
    return { initializedPromise };
};
export async function getVariableValue(key, defaultValue) {
    const { initializedPromise } = await waitForPromiseAvailable();
    await initializedPromise;
    const client = getClient();
    if (!client) {
        console.error('getVariableValue can only be called within a DevCycleServersideProvider');
        return defaultValue;
    }
    const variable = client.variable(key, defaultValue);
    return variable.value;
}
//# sourceMappingURL=getVariableValue.js.map