import { getVariableValue } from './getVariableValue';
import { getInitializedPromise, getIdentity, setInitializedPromise, } from './requestContext';
import { initialize, setupContext } from './initialize';
const ensureSetup = async (sdkKey, userGetter, options) => {
    const initializedPromise = getInitializedPromise();
    if (!initializedPromise) {
        const user = await userGetter();
        if (!user || typeof user.user_id !== 'string') {
            throw new Error('DevCycle user getter must return a user');
        }
        setupContext(sdkKey, await userGetter(), options);
        const serverDataPromise = initialize();
        setInitializedPromise(serverDataPromise);
        return { serverDataPromise };
    }
    return { serverDataPromise: initializedPromise };
};
// allow return type inference
// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
export const setupDevCycle = (sdkKey, userGetter, options = {}) => {
    const _getVariableValue = async (key, defaultValue) => {
        await ensureSetup(sdkKey, userGetter, options);
        return getVariableValue(key, defaultValue);
    };
    const _getClientContext = async () => {
        var _a;
        const { serverDataPromise } = await ensureSetup(sdkKey, userGetter, options);
        const user = getIdentity();
        if (!user) {
            throw new Error('DevCycle failed to initialize correctly. Please contact support.');
        }
        return {
            serverDataPromise,
            serverData: (options === null || options === void 0 ? void 0 : options.enableStreaming)
                ? undefined
                : await serverDataPromise,
            sdkKey: sdkKey,
            user: user,
            enableStreaming: (_a = options === null || options === void 0 ? void 0 : options.enableStreaming) !== null && _a !== void 0 ? _a : false,
        };
    };
    return {
        getVariableValue: _getVariableValue,
        getClientContext: _getClientContext,
    };
};
//# sourceMappingURL=setupDevCycle.js.map